@@ -32,6 +32,9 @@ public:
     KWin::Effect *activeFullScreenEffect() const {
         return nullptr;
     }
+    bool hasActiveFullScreenEffect() const override {
+        return false;
+    }
     int activeScreen() const override {
         return 0;
     }
@@ -260,6 +263,11 @@ public:
     }
     void hideOnScreenMessage(OnScreenMessageHideFlags flags = OnScreenMessageHideFlags()) override { Q_UNUSED(flags)}
 
+    void windowToDesktops(KWin::EffectWindow *w, const QVector<uint> &desktops) {
+        Q_UNUSED(w)
+        Q_UNUSED(desktops)
+    }
+
     KSharedConfigPtr config() const override;
     KSharedConfigPtr inputConfig() const override;
 
