@@ -20,6 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define WL_EGL_PLATFORM 1
 #include "integration.h"
 #include "window.h"
+#include "screens.h"
 #include "../../shell_client.h"
 #include "../../wayland_server.h"
 #include <logging.h>
@@ -44,7 +45,10 @@ Window::Window(QWindow *window, KWayland::Client::Surface *surface, KWayland::Cl
     , m_shellSurface(shellSurface)
     , m_windowId(++s_windowId)
     , m_integration(integration)
+    , m_scale(screens()->maxScale())
 {
+    m_surface->setScale(m_scale);
+
     QObject::connect(m_surface, &QObject::destroyed, window, [this] { m_surface = nullptr;});
     QObject::connect(m_shellSurface, &QObject::destroyed, window, [this] { m_shellSurface = nullptr;});
     waylandServer()->internalClientConection()->flush();
@@ -94,14 +98,17 @@ void Window::setGeometry(const QRect &rect)
     if (rect.height() != oldRect.height()) {
         emit window()->heightChanged(rect.height());
     }
+
+    const QSize nativeSize = rect.size() * m_scale;
+
     if (m_contentFBO) {
-        if (m_contentFBO->width() != geometry().width() || m_contentFBO->height() != geometry().height()) {
+        if (m_contentFBO->size() != nativeSize) {
             m_resized = true;
         }
     }
 #if HAVE_WAYLAND_EGL
     if (m_eglWaylandWindow) {
-        wl_egl_window_resize(m_eglWaylandWindow, geometry().width(), geometry().height(), 0, 0);
+        wl_egl_window_resize(m_eglWaylandWindow, nativeSize.width(), nativeSize.height(), 0, 0);
     }
 #endif
     QWindowSystemInterface::handleGeometryChange(window(), geometry());
@@ -124,7 +131,7 @@ void Window::unmap()
 void Window::createEglSurface(EGLDisplay dpy, EGLConfig config)
 {
 #if HAVE_WAYLAND_EGL
-    const QSize size = window()->size();
+    const QSize size = window()->size() * m_scale;
     m_eglWaylandWindow = wl_egl_window_create(*m_surface, size.width(), size.height());
     if (!m_eglWaylandWindow) {
         return;
@@ -148,6 +155,7 @@ QSharedPointer<QOpenGLFramebufferObject> Window::swapFBO()
 {
     auto fbo = m_contentFBO;
     m_contentFBO.clear();
+    m_surface->commit(KWayland::Client::Surface::CommitFlag::None);
     return fbo;
 }
 
@@ -157,7 +165,8 @@ void Window::createFBO()
     if (m_contentFBO && r.size().isEmpty()) {
         return;
     }
-    m_contentFBO.reset(new QOpenGLFramebufferObject(r.width(), r.height(), QOpenGLFramebufferObject::CombinedDepthStencil));
+    const QSize nativeSize = r.size() * m_scale;
+    m_contentFBO.reset(new QOpenGLFramebufferObject(nativeSize.width(), nativeSize.height(), QOpenGLFramebufferObject::CombinedDepthStencil));
     if (!m_contentFBO->isValid()) {
         qCWarning(KWIN_QPA) << "Content FBO is not valid";
     }
@@ -173,5 +182,15 @@ ShellClient *Window::shellClient()
     return m_shellClient;
 }
 
+int Window::scale() const
+{
+    return m_scale;
+}
+
+qreal Window::devicePixelRatio() const
+{
+    return m_scale;
+}
+
 }
 }
