@@ -228,16 +228,10 @@ protected:
     void updateTimeDiff();
     // saved data for 2nd pass of optimized screen painting
     struct Phase2Data {
-        Phase2Data(Window* w, QRegion r, QRegion c, int m, const WindowQuadList& q)
-            : window(w), region(r), clip(c), mask(m), quads(q) {}
-        Phase2Data()  {
-            window = 0;
-            mask = 0;
-        }
-        Window* window;
+        Window *window = nullptr;
         QRegion region;
         QRegion clip;
-        int mask;
+        int mask = 0;
         WindowQuadList quads;
     };
     // The region which actually has been painted by paintScreen() and should be
@@ -336,17 +330,18 @@ public:
     Shadow* shadow();
     void referencePreviousPixmap();
     void unreferencePreviousPixmap();
+    void invalidateQuadsCache();
 protected:
     WindowQuadList makeQuads(WindowQuadType type, const QRegion& reg, const QPoint &textureOffset = QPoint(0, 0), qreal textureScale = 1.0) const;
     WindowQuadList makeDecorationQuads(const QRect *rects, const QRegion &region, qreal textureScale = 1.0) const;
     /**
      * @brief Returns the WindowPixmap for this Window.
      *
-     * If the WindowPixmap does not yet exist, this method will invoke @link createWindowPixmap.
+     * If the WindowPixmap does not yet exist, this method will invoke createWindowPixmap.
      * If the WindowPixmap is not valid it tries to create it, in case this succeeds the WindowPixmap is
      * returned. In case it fails, the previous (and still valid) WindowPixmap is returned.
      *
-     * Note: this method can return @c NULL as there might neither be a valid previous nor current WindowPixmap
+     * @note This method can return @c NULL as there might neither be a valid previous nor current WindowPixmap
      * around.
      *
      * The WindowPixmap gets casted to the type passed in as a template parameter. That way this class does not
@@ -360,7 +355,7 @@ protected:
      * @brief Factory method to create a WindowPixmap.
      *
      * The inheriting classes need to implement this method to create a new instance of their WindowPixmap subclass.
-     * Note: do not use @link WindowPixmap::create on the created instance. The Scene will take care of that.
+     * @note Do not use WindowPixmap::create on the created instance. The Scene will take care of that.
      */
     virtual WindowPixmap *createWindowPixmap() = 0;
     Toplevel* toplevel;
@@ -378,17 +373,17 @@ private:
 };
 
 /**
- * @brief Wrapper for a pixmap of the @link Scene::Window.
+ * @brief Wrapper for a pixmap of the Scene::Window.
  *
  * This class encapsulates the functionality to get the pixmap for a window. When initialized the pixmap is not yet
- * mapped to the window and @link isValid will return @c false. The pixmap mapping to the window can be established
- * through @link create. If it succeeds @link isValid will return @c true, otherwise it will keep in the non valid
+ * mapped to the window and isValid will return @c false. The pixmap mapping to the window can be established
+ * through @ref create. If it succeeds isValid will return @c true, otherwise it will keep in the non valid
  * state and it can be tried to create the pixmap mapping again (e.g. in the next frame).
  *
  * This class is not intended to be updated when the pixmap is no longer valid due to e.g. resizing the window.
  * Instead a new instance of this class should be instantiated. The idea behind this is that a valid pixmap does not
  * get destroyed, but can continue to be used. To indicate that a newer pixmap should in generally be around, one can
- * use @link markAsDiscarded.
+ * use markAsDiscarded.
  *
  * This class is intended to be inherited for the needs of the compositor backends which need further mapping from
  * the native pixmap to the respective rendering format.
@@ -400,7 +395,7 @@ public:
     /**
      * @brief Tries to create the mapping between the Window and the pixmap.
      *
-     * In case this method succeeds in creating the pixmap for the window, @link isValid will return @c true otherwise
+     * In case this method succeeds in creating the pixmap for the window, isValid will return @c true otherwise
      * @c false.
      *
      * Inheriting classes should re-implement this method in case they need to add further functionality for mapping the
@@ -429,7 +424,7 @@ public:
      */
     bool isDiscarded() const;
     /**
-     * @brief Marks this WindowPixmap as discarded. From now on @link isDiscarded will return @c true. This method should
+     * @brief Marks this WindowPixmap as discarded. From now on isDiscarded will return @c true. This method should
      * only be used by the Window when it changes in a way that a new pixmap is required.
      *
      * @see isDiscarded
